API Reference
=============

.. automodule:: ytubeinsight
   :members:
   :undoc-members:
   :show-inheritance:

.. autofunction:: ytubeinsight.analyze_channel

.. autoexception:: ytubeinsight.YTubeInsightError
   :members:
   